@@ -2,7 +2,7 @@
 #
 #  __init__.py
 """
-Handy tools for working with URls and APIs.
+Handy tools for working with URLs and APIs.
 """
 #
 #  Copyright (c) 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -22,11 +22,25 @@ Handy tools for working with URls and APIs.
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#
+
+# this package
+from apeye import cache, rate_limiter
+from apeye.requests_url import RequestsURL
+from apeye.slumber_url import SlumberURL
+from apeye.url import URL, Domain, URLPath
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
-
 __license__: str = "GNU Lesser General Public License v3 or later (LGPLv3+)"
-__version__: str = "0.1.1"
+__version__: str = "0.5.0"
 __email__: str = "dominic@davis-foster.co.uk"
+
+__all__ = [
+		"URL",
+		"Domain",
+		"URLPath",
+		"RequestsURL",
+		"SlumberURL",
+		"cache",
+		"rate_limiter",
+		]
